@@ -49,10 +49,10 @@ on_activate_disk_display (GtkWidget *widget, t_disk * disk)
 
     if (disk != NULL) {
         if (disk->mount_info != NULL) { /* disk is mounted */
-            disk_umount (disk, mt->umount_command, mt->message_dialog, eject, mt->use_sudo);
+            disk_umount (disk, mt->umount_command, mt->message_dialog, eject);
         }
         else { /* disk is not mounted */
-            disk_mount (disk, mt->on_mount_cmd, mt->mount_command, eject, mt->use_sudo);
+            disk_mount (disk, mt->on_mount_cmd, mt->mount_command, eject);
         }
     }
 
@@ -379,8 +379,6 @@ mounter_read_config (XfcePanelPlugin *plugin, t_mounter *mt)
     mt->umount_command = g_strdup(xfce_rc_read_entry(rc, "umount_command", DEFAULT_UMOUNT_COMMAND));
     mt->excluded_filesystems = g_strdup(xfce_rc_read_entry(rc, "excluded_filesystems", ""));
 
-    mt->use_sudo = xfce_rc_read_bool_entry(rc, "use_sudo", FALSE);
-
     /* before 0.6.0 those booleans were stored as string "1".. handle/merge legacy configs */
     if (xfce_rc_has_entry(rc, "message_dialog"))
         mt->message_dialog = atoi(xfce_rc_read_entry(rc, "message_dialog", NULL));
@@ -442,7 +440,6 @@ mounter_write_config (XfcePanelPlugin *plugin, t_mounter *mt)
     xfce_rc_write_bool_entry (rc, "exclude_selected_filesystems", mt->exclude_FSs);
     xfce_rc_write_bool_entry (rc, "exclude_devicenames_in_menu", mt->exclude_devicenames);
     xfce_rc_write_bool_entry (rc, "eject_cddrives", mt->eject_drives);
-    xfce_rc_write_bool_entry (rc, "use_sudo", mt->use_sudo);
 
     xfce_rc_close (rc);
 
@@ -469,7 +466,6 @@ create_mounter_control (XfcePanelPlugin *plugin)
     mounter->exclude_FSs = FALSE;
     mounter->eject_drives = FALSE;
     mounter->exclude_devicenames = FALSE;
-    mounter->use_sudo = FALSE;
 
     mounter->plugin = plugin;
 
@@ -549,9 +545,6 @@ mounter_apply_options (t_mounter_dialog *md)
     mt->eject_drives = gtk_toggle_button_get_active
             (GTK_TOGGLE_BUTTON(md->show_eject_drives));
 
-    mt->use_sudo = gtk_toggle_button_get_active
-            (GTK_TOGGLE_BUTTON(md->show_use_sudo));
-
     mt->exclude_FSs = gtk_toggle_button_get_active
             (GTK_TOGGLE_BUTTON(md->show_exclude_FSs));
 
@@ -751,23 +744,6 @@ mounter_create_options (XfcePanelPlugin *plugin, t_mounter *mt)
     gtk_container_border_width (GTK_CONTAINER(_vbox), BORDER);
     gtk_widget_show (_vbox);
 
-        /* use sudo checkbox */
-    _eventbox = gtk_event_box_new ();
-    gtk_box_pack_start (GTK_BOX (_vbox), GTK_WIDGET(_eventbox),
-                        FALSE, FALSE, 0);
-    gtk_widget_show (_eventbox);
-    gtk_tooltips_set_tip ( GTK_TOOLTIPS(tip), _eventbox,
-        _("Activate this option to use sudo(8) to run mount/umount commands. Needs to be configured without password."),
-        NULL );
-
-    md->show_use_sudo = gtk_check_button_new_with_mnemonic (
-                                _("Use _sudo") );
-
-    gtk_widget_show (md->show_use_sudo);
-    gtk_container_add (GTK_CONTAINER (_eventbox), md->show_use_sudo );
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(md->show_use_sudo),
-                                mt->use_sudo);
-
         /* After-mount command */
     _eventbox = gtk_event_box_new ();
     gtk_box_pack_start (GTK_BOX (_vbox), GTK_WIDGET(_eventbox),
